Module: BasicLogging
- Included in:
- ArgParser, Configuration, HTML2Index, Template
- Defined in:
- lib/basic_logging.rb
Overview
Simplified logging. See example code at the bottom of this file. Execute this file to see the output.
Constant Summary collapse
- DEBUG =
0- INFO =
1- WARN =
2- ERROR =
3- FATAL =
4- UNKNOWN =
nil- Levels =
this is mainly for the translation of method calls into log levels
{:debug => DEBUG, :info => INFO, :warn => WARN, :error => ERROR, :fatal => FATAL, :unknown => UNKNOWN}
- @@log_level =
UNKNOWN- @@target =
STDOUT- @@muted =
[]
Class Method Summary collapse
- .is_muted?(obj) ⇒ Boolean
-
.mute(obj) ⇒ Object
do not log, if caller is obj (class or instance).
Instance Method Summary collapse
-
#clear_log ⇒ Object
Clear the log (-file).
- #level ⇒ Object
-
#log(message) ⇒ Object
(also: #debug, #info, #warn, #error, #fatal)
Output of log messages, depending on the log level set for the calling class and the name of the alias method which is actually called.
-
#set_level(lv) ⇒ Object
set the log level.
-
#set_target(tg) ⇒ Object
set the log target.
- #target ⇒ Object
Class Method Details
.is_muted?(obj) ⇒ Boolean
45 46 47 48 |
# File 'lib/basic_logging.rb', line 45 def self.is_muted?(obj) name = obj.class == Class ? obj.name.dup : obj.class.name @@muted.include?(name) end |
.mute(obj) ⇒ Object
do not log, if caller is obj (class or instance)
40 41 42 43 |
# File 'lib/basic_logging.rb', line 40 def self.mute(obj) name = obj.class == Class ? obj.name.dup : obj.class.name @@muted << name end |
Instance Method Details
#clear_log ⇒ Object
Clear the log (-file)
108 109 110 111 112 |
# File 'lib/basic_logging.rb', line 108 def clear_log if @@target && @@target.respond_to?(:truncate) lock_target{ @@target.truncate(0) } end end |
#level ⇒ Object
103 104 105 |
# File 'lib/basic_logging.rb', line 103 def level @@level.to_s if @@level end |
#log(message) ⇒ Object Also known as: debug, info, warn, error, fatal
Output of log messages, depending on the log level set for the calling class and the name of the alias method which is actually called.
85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/basic_logging.rb', line 85 def log() if !BasicLogging.is_muted?(self) # how has this method been called? mlevel = __callee__ if Levels.has_key?(mlevel) && Levels[mlevel] <= FATAL # output only for levels equal or above the value that corresponds to # the calling alias. format_log( , mlevel) if @@log_level && Levels[mlevel] >= @@log_level else STDERR.puts __FILE__.dup << ": ERROR : invalid log level \"" << mlevel.to_s << "\"" end end end |
#set_level(lv) ⇒ Object
set the log level
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/basic_logging.rb', line 51 def set_level(lv) if lv.respond_to?(:to_str) && Levels.keys.include?(lv.strip.to_sym) lv = Levels[lv.to_sym] elsif lv.respond_to?(:to_sym) && Levels.keys.include?(lv) lv = Levels[lv] end if(!lv || (lv.respond_to?(:to_int) && lv >= DEBUG && lv <= FATAL) ) @@log_level = lv else msg = __FILE__.dup << ": ERROR : invalid log level \"" << lv.to_s << "\"" msg << "\n" << "Keepinng old log level " << Levels.keys.detect {| k| Levels[k] == @@log_level}.to_s STDERR.puts msg puts msg end end |
#set_target(tg) ⇒ Object
set the log target
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/basic_logging.rb', line 69 def set_target(tg) if tg.respond_to?(:to_io) @@target = tg elsif(!File::exist?(tg) || ( File.file?(tg) && File.writable?(tg) ) ) @@target = File.open(tg, 'w+') elsif !tg || tg.respond_to?(:to_str) && tg.strip.empty? @@target = nil else STDERR.puts __FILE__.dup << ': ERROR : target ' << tg << ' cannot be set' STDERR.puts "Keeping old target " << @@target.inspect return end end |
#target ⇒ Object
99 100 101 |
# File 'lib/basic_logging.rb', line 99 def target @@target.path if @@target end |